@@ -201,16 +201,16 @@ class ImageConfig:
     def __init__(self, config: Dict[str, Any]) -> None:
         self.cmd = config.get("Command", [])
         self.entry_point = config.get("EntryPoint", [])
-        self.working_directory = config.get("WorkingDirectory", "")
+        self.working_directory = config.get("WorkingDirectory", None)
 
     def response(self) -> Dict[str, Any]:
-        return dict(
-            {
-                "Command": self.cmd,
-                "EntryPoint": self.entry_point,
-                "WorkingDirectory": self.working_directory,
-            }
-        )
+        content = {
+            "Command": self.cmd,
+            "EntryPoint": self.entry_point,
+        }
+        if self.working_directory is not None:
+            content["WorkingDirectory"] = self.working_directory
+        return dict(content)
 
 
 class Permission(CloudFormationModel):
@@ -276,9 +276,7 @@ class LayerVersion(CloudFormationModel):
                     self.code_size,
                     self.code_sha_256,
                     self.code_digest,
-                ) = _s3_content(
-                    key
-                )  # type: ignore[assignment]
+                ) = _s3_content(key)
 
     @property
     def arn(self) -> str:
@@ -481,61 +479,7 @@ class LambdaFunction(CloudFormationModel, DockerModel):
             datetime.datetime.utcnow()
         )
 
-        if "ZipFile" in self.code:
-            (
-                self.code_bytes,
-                self.code_size,
-                self.code_sha_256,
-                self.code_digest,
-            ) = _zipfile_content(self.code["ZipFile"])
-
-            # TODO: we should be putting this in a lambda bucket
-            self.code["UUID"] = str(random.uuid4())
-            self.code["S3Key"] = f"{self.function_name}-{self.code['UUID']}"
-        elif "S3Bucket" in self.code:
-            key = _validate_s3_bucket_and_key(self.account_id, data=self.code)
-            if key:
-                (
-                    self.code_bytes,
-                    self.code_size,
-                    self.code_sha_256,
-                    self.code_digest,
-                ) = _s3_content(key)
-            else:
-                self.code_bytes = b""
-                self.code_size = 0
-                self.code_sha_256 = ""
-        elif "ImageUri" in self.code:
-            if settings.lambda_stub_ecr():
-                self.code_sha_256 = hashlib.sha256(
-                    self.code["ImageUri"].encode("utf-8")
-                ).hexdigest()
-                self.code_size = 0
-            else:
-                if "@" in self.code["ImageUri"]:
-                    # deploying via digest
-                    uri, digest = self.code["ImageUri"].split("@")
-                    image_id = {"imageDigest": digest}
-                else:
-                    # deploying via tag
-                    uri, tag = self.code["ImageUri"].split(":")
-                    image_id = {"imageTag": tag}
-
-                repo_name = uri.split("/")[-1]
-                ecr_backend = ecr_backends[self.account_id][self.region]
-                registry_id = ecr_backend.describe_registry()["registryId"]
-                images = ecr_backend.batch_get_image(
-                    repository_name=repo_name, image_ids=[image_id]
-                )["images"]
-
-                if len(images) == 0:
-                    raise ImageNotFoundException(image_id, repo_name, registry_id)  # type: ignore
-                else:
-                    manifest = json.loads(images[0]["imageManifest"])
-                    self.code_sha_256 = images[0]["imageId"]["imageDigest"].replace(
-                        "sha256:", ""
-                    )
-                    self.code_size = manifest["config"]["size"]
+        self._set_function_code(self.code)
 
         self.function_arn = make_function_arn(
             self.region, self.account_id, self.function_name
@@ -713,12 +657,16 @@ class LambdaFunction(CloudFormationModel, DockerModel):
 
         return self.get_configuration()
 
-    def update_function_code(self, updated_spec: Dict[str, Any]) -> Dict[str, Any]:
-        if "DryRun" in updated_spec and updated_spec["DryRun"]:
-            return self.get_configuration()
+    def _set_function_code(self, updated_spec: Dict[str, Any]) -> None:
+        from_update = updated_spec is not self.code
+
+        # "DryRun" is only used for UpdateFunctionCode
+        if from_update and "DryRun" in updated_spec and updated_spec["DryRun"]:
+            return
 
         if "ZipFile" in updated_spec:
-            self.code["ZipFile"] = updated_spec["ZipFile"]
+            if from_update:
+                self.code["ZipFile"] = updated_spec["ZipFile"]
 
             (
                 self.code_bytes,
@@ -733,10 +681,13 @@ class LambdaFunction(CloudFormationModel, DockerModel):
         elif "S3Bucket" in updated_spec and "S3Key" in updated_spec:
             key = None
             try:
-                # FIXME: does not validate bucket region
-                key = s3_backends[self.account_id]["global"].get_object(
-                    updated_spec["S3Bucket"], updated_spec["S3Key"]
-                )
+                if from_update:
+                    # FIXME: does not validate bucket region
+                    key = s3_backends[self.account_id]["global"].get_object(
+                        updated_spec["S3Bucket"], updated_spec["S3Key"]
+                    )
+                else:
+                    key = _validate_s3_bucket_and_key(self.account_id, data=self.code)
             except MissingBucket:
                 if do_validate_s3():
                     raise ValueError(
@@ -755,12 +706,50 @@ class LambdaFunction(CloudFormationModel, DockerModel):
                     self.code_size,
                     self.code_sha_256,
                     self.code_digest,
-                ) = _s3_content(
-                    key
-                )  # type: ignore[assignment]
+                ) = _s3_content(key)
+            else:
+                self.code_bytes = b""
+                self.code_size = 0
+                self.code_sha_256 = ""
+            if from_update:
                 self.code["S3Bucket"] = updated_spec["S3Bucket"]
                 self.code["S3Key"] = updated_spec["S3Key"]
+        elif "ImageUri" in updated_spec:
+            if settings.lambda_stub_ecr():
+                self.code_sha_256 = hashlib.sha256(
+                    updated_spec["ImageUri"].encode("utf-8")
+                ).hexdigest()
+                self.code_size = 0
+            else:
+                if "@" in updated_spec["ImageUri"]:
+                    # deploying via digest
+                    uri, digest = updated_spec["ImageUri"].split("@")
+                    image_id = {"imageDigest": digest}
+                else:
+                    # deploying via tag
+                    uri, tag = updated_spec["ImageUri"].split(":")
+                    image_id = {"imageTag": tag}
 
+                repo_name = uri.split("/")[-1]
+                ecr_backend = ecr_backends[self.account_id][self.region]
+                registry_id = ecr_backend.describe_registry()["registryId"]
+                images = ecr_backend.batch_get_image(
+                    repository_name=repo_name, image_ids=[image_id]
+                )["images"]
+
+                if len(images) == 0:
+                    raise ImageNotFoundException(image_id, repo_name, registry_id)  # type: ignore
+                else:
+                    manifest = json.loads(images[0]["imageManifest"])
+                    self.code_sha_256 = images[0]["imageId"]["imageDigest"].replace(
+                        "sha256:", ""
+                    )
+                    self.code_size = manifest["config"]["size"]
+            if from_update:
+                self.code["ImageUri"] = updated_spec["ImageUri"]
+
+    def update_function_code(self, updated_spec: Dict[str, Any]) -> Dict[str, Any]:
+        self._set_function_code(updated_spec)
         return self.get_configuration()
 
     @staticmethod
@@ -772,7 +761,7 @@ class LambdaFunction(CloudFormationModel, DockerModel):
 
     def _invoke_lambda(self, event: Optional[str] = None) -> Tuple[str, bool, str]:
         # Create the LogGroup if necessary, to write the result to
-        self.logs_backend.ensure_log_group(self.logs_group_name, [])
+        self.logs_backend.ensure_log_group(self.logs_group_name)
         # TODO: context not yet implemented
         if event is None:
             event = dict()  # type: ignore[assignment]
@@ -1027,7 +1016,7 @@ class LambdaFunction(CloudFormationModel, DockerModel):
 
     def create_url_config(self, config: Dict[str, Any]) -> "FunctionUrlConfig":
         self.url_config = FunctionUrlConfig(function=self, config=config)
-        return self.url_config  # type: ignore[return-value]
+        return self.url_config
 
     def delete_url_config(self) -> None:
         self.url_config = None
@@ -1058,6 +1047,7 @@ class FunctionUrlConfig:
             "Cors": self.config.get("Cors"),
             "CreationTime": self.created,
             "LastModifiedTime": self.last_modified,
+            "InvokeMode": self.config.get("InvokeMode") or "Buffered",
         }
 
     def update(self, new_config: Dict[str, Any]) -> None:
@@ -1460,7 +1450,7 @@ class LambdaStorage(object):
     def all(self) -> Iterable[LambdaFunction]:
         result = []
 
-        for function_group in self._functions.values():
+        for function_group in list(self._functions.values()):
             latest = copy.deepcopy(function_group["latest"])
             latest.function_arn = f"{latest.function_arn}:$LATEST"
             result.append(latest)
@@ -1606,7 +1596,9 @@ class LambdaBackend(BaseBackend):
         self._layers = LayerStorage()
 
     @staticmethod
-    def default_vpc_endpoint_service(service_region: str, zones: List[str]) -> List[Dict[str, str]]:  # type: ignore[misc]
+    def default_vpc_endpoint_service(
+        service_region: str, zones: List[str]
+    ) -> List[Dict[str, str]]:
         """Default VPC endpoint service."""
         return BaseBackend.default_vpc_endpoint_service_factory(
             service_region, zones, "lambda"
@@ -1920,7 +1912,7 @@ class LambdaBackend(BaseBackend):
             ]
         }
         func = self._lambdas.get_function_by_name_or_arn(function_name, qualifier)
-        func.invoke(json.dumps(event), {}, {})  # type: ignore[union-attr]
+        func.invoke(json.dumps(event), {}, {})
 
     def send_dynamodb_items(
         self, function_arn: str, items: List[Any], source: str
@@ -2043,6 +2035,31 @@ class LambdaBackend(BaseBackend):
     def put_function_concurrency(
         self, function_name: str, reserved_concurrency: str
     ) -> str:
+        """Establish concurrency limit/reservations for a function
+
+        Actual lambda restricts concurrency to 1000 (default) per region/account
+        across all functions; we approximate that behavior by summing across all
+        functions (hopefully all in the same account and region) and allowing the
+        caller to simulate an increased quota.
+
+        By default, no quota is enforced in order to preserve compatibility with
+        existing code that assumes it can do as many things as it likes. To model
+        actual AWS behavior, define the MOTO_LAMBDA_CONCURRENCY_QUOTA environment
+        variable prior to testing.
+        """
+
+        quota: Optional[str] = os.environ.get("MOTO_LAMBDA_CONCURRENCY_QUOTA")
+        if quota is not None:
+            # Enforce concurrency limits as described above
+            available = int(quota) - int(reserved_concurrency)
+            for fnx in self.list_functions():
+                if fnx.reserved_concurrency and fnx.function_name != function_name:
+                    available -= int(fnx.reserved_concurrency)
+            if available < 100:
+                raise InvalidParameterValueException(
+                    "Specified ReservedConcurrentExecutions for function decreases account's UnreservedConcurrentExecution below its minimum value of [100]."
+                )
+
         fn = self.get_function(function_name)
         fn.reserved_concurrency = reserved_concurrency
         return fn.reserved_concurrency
