@@ -3,10 +3,7 @@ import os
 from collections import defaultdict
 from copy import copy
 from datetime import datetime, timedelta
-from cryptography.exceptions import InvalidSignature
-from cryptography.hazmat.primitives import hashes
-
-from cryptography.hazmat.primitives.asymmetric import padding
+from typing import Any, Dict, List, Tuple, Optional, Iterable, Set
 
 from moto.core import BaseBackend, BackendDict, BaseModel, CloudFormationModel
 from moto.core.utils import unix_time
@@ -22,18 +19,20 @@ from .utils import (
     generate_key_id,
     generate_master_key,
     generate_private_key,
+    KeySpec,
+    SigningAlgorithm,
 )
 
 
 class Grant(BaseModel):
     def __init__(
         self,
-        key_id,
-        name,
-        grantee_principal,
-        operations,
-        constraints,
-        retiring_principal,
+        key_id: str,
+        name: str,
+        grantee_principal: str,
+        operations: List[str],
+        constraints: Dict[str, Any],
+        retiring_principal: str,
     ):
         self.key_id = key_id
         self.name = name
@@ -44,7 +43,7 @@ class Grant(BaseModel):
         self.id = mock_random.get_random_hex()
         self.token = mock_random.get_random_hex()
 
-    def to_json(self):
+    def to_json(self) -> Dict[str, Any]:
         return {
             "KeyId": self.key_id,
             "GrantId": self.id,
@@ -59,13 +58,13 @@ class Grant(BaseModel):
 class Key(CloudFormationModel):
     def __init__(
         self,
-        policy,
-        key_usage,
-        key_spec,
-        description,
-        account_id,
-        region,
-        multi_region=False,
+        policy: Optional[str],
+        key_usage: str,
+        key_spec: str,
+        description: str,
+        account_id: str,
+        region: str,
+        multi_region: bool = False,
     ):
         self.id = generate_key_id(multi_region)
         self.creation_date = unix_time()
@@ -78,18 +77,23 @@ class Key(CloudFormationModel):
         self.region = region
         self.multi_region = multi_region
         self.key_rotation_status = False
-        self.deletion_date = None
+        self.deletion_date: Optional[datetime] = None
         self.key_material = generate_master_key()
-        self.private_key = generate_private_key()
         self.origin = "AWS_KMS"
         self.key_manager = "CUSTOMER"
         self.key_spec = key_spec or "SYMMETRIC_DEFAULT"
+        self.private_key = generate_private_key(self.key_spec)
         self.arn = f"arn:aws:kms:{region}:{account_id}:key/{self.id}"
 
-        self.grants = dict()
+        self.grants: Dict[str, Grant] = dict()
 
     def add_grant(
-        self, name, grantee_principal, operations, constraints, retiring_principal
+        self,
+        name: str,
+        grantee_principal: str,
+        operations: List[str],
+        constraints: Dict[str, Any],
+        retiring_principal: str,
     ) -> Grant:
         grant = Grant(
             self.id,
@@ -102,32 +106,32 @@ class Key(CloudFormationModel):
         self.grants[grant.id] = grant
         return grant
 
-    def list_grants(self, grant_id) -> [Grant]:
+    def list_grants(self, grant_id: str) -> List[Grant]:
         grant_ids = [grant_id] if grant_id else self.grants.keys()
         return [grant for _id, grant in self.grants.items() if _id in grant_ids]
 
-    def list_retirable_grants(self, retiring_principal) -> [Grant]:
+    def list_retirable_grants(self, retiring_principal: str) -> List[Grant]:
         return [
             grant
             for grant in self.grants.values()
             if grant.retiring_principal == retiring_principal
         ]
 
-    def revoke_grant(self, grant_id) -> None:
+    def revoke_grant(self, grant_id: str) -> None:
         if not self.grants.pop(grant_id, None):
             raise JsonRESTError("NotFoundException", f"Grant ID {grant_id} not found")
 
-    def retire_grant(self, grant_id) -> None:
+    def retire_grant(self, grant_id: str) -> None:
         self.grants.pop(grant_id, None)
 
-    def retire_grant_by_token(self, grant_token) -> None:
+    def retire_grant_by_token(self, grant_token: str) -> None:
         self.grants = {
             _id: grant
             for _id, grant in self.grants.items()
             if grant.token != grant_token
         }
 
-    def generate_default_policy(self):
+    def generate_default_policy(self) -> str:
         return json.dumps(
             {
                 "Version": "2012-10-17",
@@ -145,11 +149,11 @@ class Key(CloudFormationModel):
         )
 
     @property
-    def physical_resource_id(self):
+    def physical_resource_id(self) -> str:
         return self.id
 
     @property
-    def encryption_algorithms(self):
+    def encryption_algorithms(self) -> Optional[List[str]]:
         if self.key_usage == "SIGN_VERIFY":
             return None
         elif self.key_spec == "SYMMETRIC_DEFAULT":
@@ -158,26 +162,25 @@ class Key(CloudFormationModel):
             return ["RSAES_OAEP_SHA_1", "RSAES_OAEP_SHA_256"]
 
     @property
-    def signing_algorithms(self):
+    def signing_algorithms(self) -> List[str]:
         if self.key_usage == "ENCRYPT_DECRYPT":
-            return None
-        elif self.key_spec in ["ECC_NIST_P256", "ECC_SECG_P256K1"]:
-            return ["ECDSA_SHA_256"]
-        elif self.key_spec == "ECC_NIST_P384":
-            return ["ECDSA_SHA_384"]
-        elif self.key_spec == "ECC_NIST_P521":
-            return ["ECDSA_SHA_512"]
+            return None  # type: ignore[return-value]
+        elif self.key_spec in KeySpec.ecc_key_specs():
+            if self.key_spec == KeySpec.ECC_NIST_P384:
+                return [SigningAlgorithm.ECDSA_SHA_384.value]
+            elif self.key_spec == KeySpec.ECC_NIST_P521:
+                return [SigningAlgorithm.ECDSA_SHA_512.value]
+            else:
+                # key_spec is 'ECC_NIST_P256' or 'ECC_SECG_P256K1'
+                return [SigningAlgorithm.ECDSA_SHA_256.value]
+        elif self.key_spec in KeySpec.rsa_key_specs():
+            return SigningAlgorithm.rsa_signing_algorithms()
+        elif self.key_spec == KeySpec.SM2:
+            return [SigningAlgorithm.SM2DSA.value]
         else:
-            return [
-                "RSASSA_PKCS1_V1_5_SHA_256",
-                "RSASSA_PKCS1_V1_5_SHA_384",
-                "RSASSA_PKCS1_V1_5_SHA_512",
-                "RSASSA_PSS_SHA_256",
-                "RSASSA_PSS_SHA_384",
-                "RSASSA_PSS_SHA_512",
-            ]
+            return []
 
-    def to_dict(self):
+    def to_dict(self) -> Dict[str, Any]:
         key_dict = {
             "KeyMetadata": {
                 "AWSAccountId": self.account_id,
@@ -201,22 +204,27 @@ class Key(CloudFormationModel):
             key_dict["KeyMetadata"]["DeletionDate"] = unix_time(self.deletion_date)
         return key_dict
 
-    def delete(self, account_id, region_name):
+    def delete(self, account_id: str, region_name: str) -> None:
         kms_backends[account_id][region_name].delete_key(self.id)
 
     @staticmethod
-    def cloudformation_name_type():
-        return None
+    def cloudformation_name_type() -> str:
+        return ""
 
     @staticmethod
-    def cloudformation_type():
+    def cloudformation_type() -> str:
         # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kms-key.html
         return "AWS::KMS::Key"
 
     @classmethod
-    def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, account_id, region_name, **kwargs
-    ):
+    def create_from_cloudformation_json(  # type: ignore[misc]
+        cls,
+        resource_name: str,
+        cloudformation_json: Any,
+        account_id: str,
+        region_name: str,
+        **kwargs: Any,
+    ) -> "Key":
         kms_backend = kms_backends[account_id][region_name]
         properties = cloudformation_json["Properties"]
 
@@ -233,10 +241,10 @@ class Key(CloudFormationModel):
         return key
 
     @classmethod
-    def has_cfn_attr(cls, attr):
+    def has_cfn_attr(cls, attr: str) -> bool:
         return attr in ["Arn"]
 
-    def get_cfn_attribute(self, attribute_name):
+    def get_cfn_attribute(self, attribute_name: str) -> str:
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
 
         if attribute_name == "Arn":
@@ -245,20 +253,22 @@ class Key(CloudFormationModel):
 
 
 class KmsBackend(BaseBackend):
-    def __init__(self, region_name, account_id=None):
-        super().__init__(region_name=region_name, account_id=account_id)
-        self.keys = {}
-        self.key_to_aliases = defaultdict(set)
+    def __init__(self, region_name: str, account_id: Optional[str] = None):
+        super().__init__(region_name=region_name, account_id=account_id)  # type: ignore
+        self.keys: Dict[str, Key] = {}
+        self.key_to_aliases: Dict[str, Set[str]] = defaultdict(set)
         self.tagger = TaggingService(key_name="TagKey", value_name="TagValue")
 
     @staticmethod
-    def default_vpc_endpoint_service(service_region, zones):
+    def default_vpc_endpoint_service(
+        service_region: str, zones: List[str]
+    ) -> List[Dict[str, str]]:
         """Default VPC endpoint service."""
         return BaseBackend.default_vpc_endpoint_service_factory(
             service_region, zones, "kms"
         )
 
-    def _generate_default_keys(self, alias_name):
+    def _generate_default_keys(self, alias_name: str) -> Optional[str]:
         """Creates default kms keys"""
         if alias_name in RESERVED_ALIASES:
             key = self.create_key(
@@ -270,10 +280,17 @@ class KmsBackend(BaseBackend):
             )
             self.add_alias(key.id, alias_name)
             return key.id
+        return None
 
     def create_key(
-        self, policy, key_usage, key_spec, description, tags, multi_region=False
-    ):
+        self,
+        policy: Optional[str],
+        key_usage: str,
+        key_spec: str,
+        description: str,
+        tags: Optional[List[Dict[str, str]]],
+        multi_region: bool = False,
+    ) -> Key:
         """
         The provided Policy currently does not need to be valid. If it is valid, Moto will perform authorization checks on key-related operations, just like AWS does.
 
@@ -282,6 +299,8 @@ class KmsBackend(BaseBackend):
          - The resource is set to "*"
          - The Action matches `describe_key`
         """
+        if key_spec:
+            self.__ensure_valid_key_spec(key_spec)
         key = Key(
             policy,
             key_usage,
@@ -303,7 +322,7 @@ class KmsBackend(BaseBackend):
     #
     # In our implementation with just create a copy of all the properties once without any protection from change,
     # as the exact implementation is currently infeasible.
-    def replicate_key(self, key_id, replica_region):
+    def replicate_key(self, key_id: str, replica_region: str) -> None:
         # Using copy() instead of deepcopy(), as the latter results in exception:
         #    TypeError: cannot pickle '_cffi_backend.FFI' object
         # Since we only update top level properties, copy() should suffice.
@@ -312,31 +331,31 @@ class KmsBackend(BaseBackend):
         to_region_backend = kms_backends[self.account_id][replica_region]
         to_region_backend.keys[replica_key.id] = replica_key
 
-    def update_key_description(self, key_id, description):
+    def update_key_description(self, key_id: str, description: str) -> None:
         key = self.keys[self.get_key_id(key_id)]
         key.description = description
 
-    def delete_key(self, key_id):
+    def delete_key(self, key_id: str) -> None:
         if key_id in self.keys:
             if key_id in self.key_to_aliases:
                 self.key_to_aliases.pop(key_id)
             self.tagger.delete_all_tags_for_resource(key_id)
 
-            return self.keys.pop(key_id)
+            self.keys.pop(key_id)
 
-    def describe_key(self, key_id) -> Key:
+    def describe_key(self, key_id: str) -> Key:
         # allow the different methods (alias, ARN :key/, keyId, ARN alias) to
         # describe key not just KeyId
         key_id = self.get_key_id(key_id)
         if r"alias/" in str(key_id).lower():
-            key_id = self.get_key_id_from_alias(key_id)
+            key_id = self.get_key_id_from_alias(key_id)  # type: ignore[assignment]
         return self.keys[self.get_key_id(key_id)]
 
-    def list_keys(self):
+    def list_keys(self) -> Iterable[Key]:
         return self.keys.values()
 
     @staticmethod
-    def get_key_id(key_id):
+    def get_key_id(key_id: str) -> str:
         # Allow use of ARN as well as pure KeyId
         if key_id.startswith("arn:") and ":key/" in key_id:
             return key_id.split(":key/")[1]
@@ -344,14 +363,14 @@ class KmsBackend(BaseBackend):
         return key_id
 
     @staticmethod
-    def get_alias_name(alias_name):
+    def get_alias_name(alias_name: str) -> str:
         # Allow use of ARN as well as alias name
         if alias_name.startswith("arn:") and ":alias/" in alias_name:
             return "alias/" + alias_name.split(":alias/")[1]
 
         return alias_name
 
-    def any_id_to_key_id(self, key_id):
+    def any_id_to_key_id(self, key_id: str) -> str:
         """Go from any valid key ID to the raw key ID.
 
         Acceptable inputs:
@@ -363,66 +382,65 @@ class KmsBackend(BaseBackend):
         key_id = self.get_alias_name(key_id)
         key_id = self.get_key_id(key_id)
         if key_id.startswith("alias/"):
-            key_id = self.get_key_id(self.get_key_id_from_alias(key_id))
+            key_id = self.get_key_id(self.get_key_id_from_alias(key_id))  # type: ignore[arg-type]
         return key_id
 
-    def alias_exists(self, alias_name):
+    def alias_exists(self, alias_name: str) -> bool:
         for aliases in self.key_to_aliases.values():
             if alias_name in aliases:
                 return True
 
         return False
 
-    def add_alias(self, target_key_id, alias_name):
+    def add_alias(self, target_key_id: str, alias_name: str) -> None:
         raw_key_id = self.get_key_id(target_key_id)
         self.key_to_aliases[raw_key_id].add(alias_name)
 
-    def delete_alias(self, alias_name):
+    def delete_alias(self, alias_name: str) -> None:
         """Delete the alias."""
         for aliases in self.key_to_aliases.values():
             if alias_name in aliases:
                 aliases.remove(alias_name)
 
-    def get_all_aliases(self):
+    def get_all_aliases(self) -> Dict[str, Set[str]]:
         return self.key_to_aliases
 
-    def get_key_id_from_alias(self, alias_name):
+    def get_key_id_from_alias(self, alias_name: str) -> Optional[str]:
         for key_id, aliases in dict(self.key_to_aliases).items():
             if alias_name in ",".join(aliases):
                 return key_id
         if alias_name in RESERVED_ALIASES:
-            key_id = self._generate_default_keys(alias_name)
-            return key_id
+            return self._generate_default_keys(alias_name)
         return None
 
-    def enable_key_rotation(self, key_id):
+    def enable_key_rotation(self, key_id: str) -> None:
         self.keys[self.get_key_id(key_id)].key_rotation_status = True
 
-    def disable_key_rotation(self, key_id):
+    def disable_key_rotation(self, key_id: str) -> None:
         self.keys[self.get_key_id(key_id)].key_rotation_status = False
 
-    def get_key_rotation_status(self, key_id):
+    def get_key_rotation_status(self, key_id: str) -> bool:
         return self.keys[self.get_key_id(key_id)].key_rotation_status
 
-    def put_key_policy(self, key_id, policy):
+    def put_key_policy(self, key_id: str, policy: str) -> None:
         self.keys[self.get_key_id(key_id)].policy = policy
 
-    def get_key_policy(self, key_id):
+    def get_key_policy(self, key_id: str) -> str:
         return self.keys[self.get_key_id(key_id)].policy
 
-    def disable_key(self, key_id):
+    def disable_key(self, key_id: str) -> None:
         self.keys[key_id].enabled = False
         self.keys[key_id].key_state = "Disabled"
 
-    def enable_key(self, key_id):
+    def enable_key(self, key_id: str) -> None:
         self.keys[key_id].enabled = True
         self.keys[key_id].key_state = "Enabled"
 
-    def cancel_key_deletion(self, key_id):
+    def cancel_key_deletion(self, key_id: str) -> None:
         self.keys[key_id].key_state = "Disabled"
         self.keys[key_id].deletion_date = None
 
-    def schedule_key_deletion(self, key_id, pending_window_in_days):
+    def schedule_key_deletion(self, key_id: str, pending_window_in_days: int) -> float:  # type: ignore[return]
         if 7 <= pending_window_in_days <= 30:
             self.keys[key_id].enabled = False
             self.keys[key_id].key_state = "PendingDeletion"
@@ -431,7 +449,9 @@ class KmsBackend(BaseBackend):
             )
             return unix_time(self.keys[key_id].deletion_date)
 
-    def encrypt(self, key_id, plaintext, encryption_context):
+    def encrypt(
+        self, key_id: str, plaintext: bytes, encryption_context: Dict[str, str]
+    ) -> Tuple[bytes, str]:
         key_id = self.any_id_to_key_id(key_id)
 
         ciphertext_blob = encrypt(
@@ -443,7 +463,9 @@ class KmsBackend(BaseBackend):
         arn = self.keys[key_id].arn
         return ciphertext_blob, arn
 
-    def decrypt(self, ciphertext_blob, encryption_context):
+    def decrypt(
+        self, ciphertext_blob: bytes, encryption_context: Dict[str, str]
+    ) -> Tuple[bytes, str]:
         plaintext, key_id = decrypt(
             master_keys=self.keys,
             ciphertext_blob=ciphertext_blob,
@@ -454,11 +476,11 @@ class KmsBackend(BaseBackend):
 
     def re_encrypt(
         self,
-        ciphertext_blob,
-        source_encryption_context,
-        destination_key_id,
-        destination_encryption_context,
-    ):
+        ciphertext_blob: bytes,
+        source_encryption_context: Dict[str, str],
+        destination_key_id: str,
+        destination_encryption_context: Dict[str, str],
+    ) -> Tuple[bytes, str, str]:
         destination_key_id = self.any_id_to_key_id(destination_key_id)
 
         plaintext, decrypting_arn = self.decrypt(
@@ -472,7 +494,13 @@ class KmsBackend(BaseBackend):
         )
         return new_ciphertext_blob, decrypting_arn, encrypting_arn
 
-    def generate_data_key(self, key_id, encryption_context, number_of_bytes, key_spec):
+    def generate_data_key(
+        self,
+        key_id: str,
+        encryption_context: Dict[str, str],
+        number_of_bytes: int,
+        key_spec: str,
+    ) -> Tuple[bytes, bytes, str]:
         key_id = self.any_id_to_key_id(key_id)
 
         if key_spec:
@@ -492,7 +520,7 @@ class KmsBackend(BaseBackend):
 
         return plaintext, ciphertext_blob, arn
 
-    def list_resource_tags(self, key_id_or_arn):
+    def list_resource_tags(self, key_id_or_arn: str) -> Dict[str, List[Dict[str, str]]]:
         key_id = self.get_key_id(key_id_or_arn)
         if key_id in self.keys:
             return self.tagger.list_tags_for_resource(key_id)
@@ -501,21 +529,21 @@ class KmsBackend(BaseBackend):
             "The request was rejected because the specified entity or resource could not be found.",
         )
 
-    def tag_resource(self, key_id_or_arn, tags):
+    def tag_resource(self, key_id_or_arn: str, tags: List[Dict[str, str]]) -> None:
         key_id = self.get_key_id(key_id_or_arn)
         if key_id in self.keys:
             self.tagger.tag_resource(key_id, tags)
-            return {}
+            return
         raise JsonRESTError(
             "NotFoundException",
             "The request was rejected because the specified entity or resource could not be found.",
         )
 
-    def untag_resource(self, key_id_or_arn, tag_names):
+    def untag_resource(self, key_id_or_arn: str, tag_names: List[str]) -> None:
         key_id = self.get_key_id(key_id_or_arn)
         if key_id in self.keys:
             self.tagger.untag_resource_using_names(key_id, tag_names)
-            return {}
+            return
         raise JsonRESTError(
             "NotFoundException",
             "The request was rejected because the specified entity or resource could not be found.",
@@ -523,13 +551,13 @@ class KmsBackend(BaseBackend):
 
     def create_grant(
         self,
-        key_id,
-        grantee_principal,
-        operations,
-        name,
-        constraints,
-        retiring_principal,
-    ):
+        key_id: str,
+        grantee_principal: str,
+        operations: List[str],
+        name: str,
+        constraints: Dict[str, Any],
+        retiring_principal: str,
+    ) -> Tuple[str, str]:
         key = self.describe_key(key_id)
         grant = key.add_grant(
             name,
@@ -540,21 +568,21 @@ class KmsBackend(BaseBackend):
         )
         return grant.id, grant.token
 
-    def list_grants(self, key_id, grant_id) -> [Grant]:
+    def list_grants(self, key_id: str, grant_id: str) -> List[Grant]:
         key = self.describe_key(key_id)
         return key.list_grants(grant_id)
 
-    def list_retirable_grants(self, retiring_principal):
+    def list_retirable_grants(self, retiring_principal: str) -> List[Grant]:
         grants = []
         for key in self.keys.values():
             grants.extend(key.list_retirable_grants(retiring_principal))
         return grants
 
-    def revoke_grant(self, key_id, grant_id) -> None:
+    def revoke_grant(self, key_id: str, grant_id: str) -> None:
         key = self.describe_key(key_id)
         key.revoke_grant(grant_id)
 
-    def retire_grant(self, key_id, grant_id, grant_token) -> None:
+    def retire_grant(self, key_id: str, grant_id: str, grant_token: str) -> None:
         if grant_token:
             for key in self.keys.values():
                 key.retire_grant_by_token(grant_token)
@@ -562,7 +590,7 @@ class KmsBackend(BaseBackend):
             key = self.describe_key(key_id)
             key.retire_grant(grant_id)
 
-    def __ensure_valid_sign_and_verify_key(self, key: Key):
+    def __ensure_valid_sign_and_verify_key(self, key: Key) -> None:
         if key.key_usage != "SIGN_VERIFY":
             raise ValidationException(
                 (
@@ -571,7 +599,9 @@ class KmsBackend(BaseBackend):
                 ).format(key_id=key.id)
             )
 
-    def __ensure_valid_signing_augorithm(self, key: Key, signing_algorithm):
+    def __ensure_valid_signing_algorithm(
+        self, key: Key, signing_algorithm: str
+    ) -> None:
         if signing_algorithm not in key.signing_algorithms:
             raise ValidationException(
                 (
@@ -584,7 +614,19 @@ class KmsBackend(BaseBackend):
                 )
             )
 
-    def sign(self, key_id, message, signing_algorithm):
+    def __ensure_valid_key_spec(self, key_spec: str) -> None:
+        if key_spec not in KeySpec.key_specs():
+            raise ValidationException(
+                (
+                    "1 validation error detected: Value '{key_spec}' at 'KeySpec' failed "
+                    "to satisfy constraint: Member must satisfy enum value set: "
+                    "{valid_key_specs}"
+                ).format(key_spec=key_spec, valid_key_specs=KeySpec.key_specs())
+            )
+
+    def sign(
+        self, key_id: str, message: bytes, signing_algorithm: str
+    ) -> Tuple[str, bytes, str]:
         """Sign message using generated private key.
 
         - signing_algorithm is ignored and hardcoded to RSASSA_PSS_SHA_256
@@ -594,20 +636,15 @@ class KmsBackend(BaseBackend):
         key = self.describe_key(key_id)
 
         self.__ensure_valid_sign_and_verify_key(key)
-        self.__ensure_valid_signing_augorithm(key, signing_algorithm)
+        self.__ensure_valid_signing_algorithm(key, signing_algorithm)
 
-        # TODO: support more than one hardcoded algorithm based on KeySpec
-        signature = key.private_key.sign(
-            message,
-            padding.PSS(
-                mgf=padding.MGF1(hashes.SHA256()), salt_length=padding.PSS.MAX_LENGTH
-            ),
-            hashes.SHA256(),
-        )
+        signature = key.private_key.sign(message, signing_algorithm)
 
         return key.arn, signature, signing_algorithm
 
-    def verify(self, key_id, message, signature, signing_algorithm):
+    def verify(
+        self, key_id: str, message: bytes, signature: bytes, signing_algorithm: str
+    ) -> Tuple[str, bool, str]:
         """Verify message using public key from generated private key.
 
         - signing_algorithm is ignored and hardcoded to RSASSA_PSS_SHA_256
@@ -617,7 +654,7 @@ class KmsBackend(BaseBackend):
         key = self.describe_key(key_id)
 
         self.__ensure_valid_sign_and_verify_key(key)
-        self.__ensure_valid_signing_augorithm(key, signing_algorithm)
+        self.__ensure_valid_signing_algorithm(key, signing_algorithm)
 
         if signing_algorithm not in key.signing_algorithms:
             raise ValidationException(
@@ -631,22 +668,15 @@ class KmsBackend(BaseBackend):
                 )
             )
 
-        public_key = key.private_key.public_key()
+        return (
+            key.arn,
+            key.private_key.verify(message, signature, signing_algorithm),
+            signing_algorithm,
+        )
 
-        try:
-            # TODO: support more than one hardcoded algorithm based on KeySpec
-            public_key.verify(
-                signature,
-                message,
-                padding.PSS(
-                    mgf=padding.MGF1(hashes.SHA256()),
-                    salt_length=padding.PSS.MAX_LENGTH,
-                ),
-                hashes.SHA256(),
-            )
-            return key.arn, True, signing_algorithm
-        except InvalidSignature:
-            return key.arn, False, signing_algorithm
+    def get_public_key(self, key_id: str) -> Tuple[Key, bytes]:
+        key = self.describe_key(key_id)
+        return key, key.private_key.public_key()
 
 
 kms_backends = BackendDict(KmsBackend, "kms")
