@@ -1,23 +1,25 @@
 """Handles incoming mq requests, invokes methods, returns responses."""
 import json
+from typing import Any
 from urllib.parse import unquote
 
+from moto.core.common_types import TYPE_RESPONSE
 from moto.core.responses import BaseResponse
-from .models import mq_backends
+from .models import mq_backends, MQBackend
 
 
 class MQResponse(BaseResponse):
     """Handler for MQ requests and responses."""
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(service_name="mq")
 
     @property
-    def mq_backend(self):
+    def mq_backend(self) -> MQBackend:
         """Return backend instance specific for this region."""
         return mq_backends[self.current_account][self.region]
 
-    def broker(self, request, full_url, headers):
+    def broker(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "GET":
             return self.describe_broker()
@@ -26,40 +28,42 @@ class MQResponse(BaseResponse):
         if request.method == "PUT":
             return self.update_broker()
 
-    def brokers(self, request, full_url, headers):
+    def brokers(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
             return self.create_broker()
         if request.method == "GET":
             return self.list_brokers()
 
-    def configuration(self, request, full_url, headers):
+    def configuration(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "GET":
             return self.describe_configuration()
         if request.method == "PUT":
             return self.update_configuration()
 
-    def configurations(self, request, full_url, headers):
+    def configurations(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
             return self.create_configuration()
         if request.method == "GET":
             return self.list_configurations()
 
-    def configuration_revision(self, request, full_url, headers):
+    def configuration_revision(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "GET":
             return self.get_configuration_revision()
 
-    def tags(self, request, full_url, headers):
+    def tags(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
             return self.create_tags()
         if request.method == "DELETE":
             return self.delete_tags()
+        if request.method == "GET":
+            return self.list_tags()
 
-    def user(self, request, full_url, headers):
+    def user(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
             return self.create_user()
@@ -70,12 +74,12 @@ class MQResponse(BaseResponse):
         if request.method == "DELETE":
             return self.delete_user()
 
-    def users(self, request, full_url, headers):
+    def users(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "GET":
             return self.list_users()
 
-    def create_broker(self):
+    def create_broker(self) -> TYPE_RESPONSE:
         params = json.loads(self.body)
         authentication_strategy = params.get("authenticationStrategy")
         auto_minor_version_upgrade = params.get("autoMinorVersionUpgrade")
@@ -119,7 +123,7 @@ class MQResponse(BaseResponse):
         resp = {"brokerArn": broker_arn, "brokerId": broker_id}
         return 200, {}, json.dumps(resp)
 
-    def update_broker(self):
+    def update_broker(self) -> TYPE_RESPONSE:
         params = json.loads(self.body)
         broker_id = self.path.split("/")[-1]
         authentication_strategy = params.get("authenticationStrategy")
@@ -145,23 +149,23 @@ class MQResponse(BaseResponse):
         )
         return self.describe_broker()
 
-    def delete_broker(self):
+    def delete_broker(self) -> TYPE_RESPONSE:
         broker_id = self.path.split("/")[-1]
         self.mq_backend.delete_broker(broker_id=broker_id)
         return 200, {}, json.dumps(dict(brokerId=broker_id))
 
-    def describe_broker(self):
+    def describe_broker(self) -> TYPE_RESPONSE:
         broker_id = self.path.split("/")[-1]
         broker = self.mq_backend.describe_broker(broker_id=broker_id)
         resp = broker.to_json()
         resp["tags"] = self.mq_backend.list_tags(broker.arn)
         return 200, {}, json.dumps(resp)
 
-    def list_brokers(self):
+    def list_brokers(self) -> TYPE_RESPONSE:
         brokers = self.mq_backend.list_brokers()
         return 200, {}, json.dumps(dict(brokerSummaries=[b.summary() for b in brokers]))
 
-    def create_user(self):
+    def create_user(self) -> TYPE_RESPONSE:
         params = json.loads(self.body)
         broker_id = self.path.split("/")[-3]
         username = self.path.split("/")[-1]
@@ -170,7 +174,7 @@ class MQResponse(BaseResponse):
         self.mq_backend.create_user(broker_id, username, console_access, groups)
         return 200, {}, "{}"
 
-    def update_user(self):
+    def update_user(self) -> TYPE_RESPONSE:
         params = json.loads(self.body)
         broker_id = self.path.split("/")[-3]
         username = self.path.split("/")[-1]
@@ -184,19 +188,19 @@ class MQResponse(BaseResponse):
         )
         return 200, {}, "{}"
 
-    def describe_user(self):
+    def describe_user(self) -> TYPE_RESPONSE:
         broker_id = self.path.split("/")[-3]
         username = self.path.split("/")[-1]
         user = self.mq_backend.describe_user(broker_id, username)
         return 200, {}, json.dumps(user.to_json())
 
-    def delete_user(self):
+    def delete_user(self) -> TYPE_RESPONSE:
         broker_id = self.path.split("/")[-3]
         username = self.path.split("/")[-1]
         self.mq_backend.delete_user(broker_id, username)
         return 200, {}, "{}"
 
-    def list_users(self):
+    def list_users(self) -> TYPE_RESPONSE:
         broker_id = self.path.split("/")[-2]
         users = self.mq_backend.list_users(broker_id=broker_id)
         resp = {
@@ -205,7 +209,7 @@ class MQResponse(BaseResponse):
         }
         return 200, {}, json.dumps(resp)
 
-    def create_configuration(self):
+    def create_configuration(self) -> TYPE_RESPONSE:
         params = json.loads(self.body)
         name = params.get("name")
         engine_type = params.get("engineType")
@@ -217,19 +221,19 @@ class MQResponse(BaseResponse):
         )
         return 200, {}, json.dumps(config.to_json())
 
-    def describe_configuration(self):
+    def describe_configuration(self) -> TYPE_RESPONSE:
         config_id = self.path.split("/")[-1]
         config = self.mq_backend.describe_configuration(config_id)
         resp = config.to_json()
         resp["tags"] = self.mq_backend.list_tags(config.arn)
         return 200, {}, json.dumps(resp)
 
-    def list_configurations(self):
+    def list_configurations(self) -> TYPE_RESPONSE:
         configs = self.mq_backend.list_configurations()
         resp = {"configurations": [c.to_json() for c in configs]}
         return 200, {}, json.dumps(resp)
 
-    def update_configuration(self):
+    def update_configuration(self) -> TYPE_RESPONSE:
         config_id = self.path.split("/")[-1]
         params = json.loads(self.body)
         data = params.get("data")
@@ -237,7 +241,7 @@ class MQResponse(BaseResponse):
         config = self.mq_backend.update_configuration(config_id, data, description)
         return 200, {}, json.dumps(config.to_json())
 
-    def get_configuration_revision(self):
+    def get_configuration_revision(self) -> TYPE_RESPONSE:
         revision_id = self.path.split("/")[-1]
         config_id = self.path.split("/")[-3]
         revision = self.mq_backend.describe_configuration_revision(
@@ -245,19 +249,24 @@ class MQResponse(BaseResponse):
         )
         return 200, {}, json.dumps(revision.to_json())
 
-    def create_tags(self):
+    def create_tags(self) -> TYPE_RESPONSE:
         resource_arn = unquote(self.path.split("/")[-1])
         tags = json.loads(self.body).get("tags", {})
         self.mq_backend.create_tags(resource_arn, tags)
         return 200, {}, "{}"
 
-    def delete_tags(self):
+    def delete_tags(self) -> TYPE_RESPONSE:
         resource_arn = unquote(self.path.split("/")[-1])
         tag_keys = self._get_param("tagKeys")
         self.mq_backend.delete_tags(resource_arn, tag_keys)
         return 200, {}, "{}"
 
-    def reboot(self, request, full_url, headers):
+    def list_tags(self) -> TYPE_RESPONSE:
+        resource_arn = unquote(self.path.split("/")[-1])
+        tags = self.mq_backend.list_tags(resource_arn)
+        return 200, {}, json.dumps({"tags": tags})
+
+    def reboot(self, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore[return]
         self.setup_class(request, full_url, headers)
         if request.method == "POST":
             broker_id = self.path.split("/")[-2]
