@@ -116,7 +116,7 @@ class RDSResponse(BaseResponse):
             "enable_iam_database_authentication": self._get_bool_param(
                 "EnableIAMDatabaseAuthentication"
             ),
-            "enable_http_endpoint": self._get_param("EnableHttpEndpoint"),
+            "enable_http_endpoint": self._get_bool_param("EnableHttpEndpoint"),
             "license_model": self._get_param("LicenseModel"),
             "iops": self._get_int_param("Iops"),
             "kms_key_id": self._get_param("KmsKeyId"),
@@ -178,13 +178,12 @@ class RDSResponse(BaseResponse):
         }
 
     def _get_db_cluster_kwargs(self) -> Dict[str, Any]:
+        params = self._get_params()
         return {
             "availability_zones": self._get_multi_param(
                 "AvailabilityZones.AvailabilityZone"
             ),
-            "enable_cloudwatch_logs_exports": self._get_params().get(
-                "EnableCloudwatchLogsExports"
-            ),
+            "enable_cloudwatch_logs_exports": params.get("EnableCloudwatchLogsExports"),
             "db_name": self._get_param("DatabaseName"),
             "db_cluster_identifier": self._get_param("DBClusterIdentifier"),
             "db_subnet_group_name": self._get_param("DBSubnetGroupName"),
@@ -204,13 +203,19 @@ class RDSResponse(BaseResponse):
             "parameter_group": self._get_param("DBClusterParameterGroupName"),
             "region": self.region,
             "db_cluster_instance_class": self._get_param("DBClusterInstanceClass"),
-            "enable_http_endpoint": self._get_param("EnableHttpEndpoint"),
+            "enable_http_endpoint": self._get_bool_param("EnableHttpEndpoint"),
             "copy_tags_to_snapshot": self._get_param("CopyTagsToSnapshot"),
             "tags": self.unpack_list_params("Tags", "Tag"),
             "scaling_configuration": self._get_dict_param("ScalingConfiguration."),
+            "serverless_v2_scaling_configuration": params.get(
+                "ServerlessV2ScalingConfiguration"
+            ),
             "replication_source_identifier": self._get_param(
                 "ReplicationSourceIdentifier"
             ),
+            "vpc_security_group_ids": self.unpack_list_params(
+                "VpcSecurityGroupIds", "VpcSecurityGroupId"
+            ),
         }
 
     def _get_export_task_kwargs(self) -> Dict[str, Any]:
